# Edit this configuration file to define what should be installed on
# your system. Help is available in the configuration.nix(5) man page, on
# https://search.nixos.org/options and in the NixOS manual (`nixos-help`).

{
  imports = [
    ./hardware-configuration.nix
    ../../roles/laptop.nix
    ../../roles/zfs.nix
    ../../roles/avahi.nix
    ../../roles/restic.nix
    ../../base.nix
    ../../users/root.nix
    ../../users/nolan/desktop.nix
    ../../roles/espeakup.nix
    ../../roles/networkmanager.nix
    ../../roles/nix-ld.nix
    ../../roles/tailscale.nix
    ../../roles/podman.nix
    ../../roles/syncthing.nix
    ../../roles/gnome.nix
    ../../roles/flatpak.nix
    ../../roles/games.nix
  ];

  boot = {
    loader = {
      efi.canTouchEfiVariables = true;
      systemd-boot.enable = true;
    };
    supportedFilesystems = [ "zfs" ];
  };

  networking = {
    hostName = "flynode";
    hostId = "9dfa34d8";
  };

  time.timeZone = "America/Chicago";

  i18n.defaultLocale = "en_US.UTF-8";
  console.keyMap = "us";

  # Enable the Flakes feature and the accompanying new nix command-line tool
  nix.settings.experimental-features = [
    "nix-command"
    "flakes"
  ];

  services.syncthing = {
    user = "nolan";
    group = "users";
    dataDir = "/home/nolan";
  };

  age.identityPaths = [ "/root/.ssh/id_rsa" ];

  # This option defines the first version of NixOS you have installed on this particular machine,
  # and is used to maintain compatibility with application data (e.g. databases) created on older NixOS versions.
  #
  # Most users should NEVER change this value after the initial install, for any reason,
  # even if you've upgraded your system to a new NixOS release.
  #
  # This value does NOT affect the Nixpkgs version your packages and OS are pulled from,
  # so changing it will NOT upgrade your system - see https://nixos.org/manual/nixos/stable/#sec-upgrading for how
  # to actually do that.
  #
  # This value being lower than the current NixOS release does NOT mean your system is
  # out of date, out of support, or vulnerable.
  #
  # Do NOT change this value unless you have manually inspected all the changes it would make to your configuration,
  # and migrated your data accordingly.
  #
  # For more information, see `man configuration.nix` or https://nixos.org/manual/nixos/stable/options#opt-system.stateVersion .
  system.stateVersion = "24.05"; # Did you read the comment?
}
